@@ -142,9 +142,9 @@ set_displayed_location (NautilusWindowSlot *slot, GFile *location)
 			g_object_unref (slot->last_location_bookmark);
                 }
 		slot->last_location_bookmark = slot->current_location_bookmark;
-		name = g_file_get_uri (location);
+		name = g_file_get_basename (location);
 		slot->current_location_bookmark = (location == NULL) ? NULL
-                        : nautilus_bookmark_new (location, name, TRUE, NULL);
+                        : nautilus_bookmark_new (location, name, FALSE, NULL);
 		g_free (name);
         }
 }
@@ -1062,6 +1062,7 @@ got_file_info_for_view_selection_callback (NautilusFile *file,
 		slot->tried_mount = TRUE;
 
 		mount_op = gtk_mount_operation_new (GTK_WINDOW (window));
+		g_mount_operation_set_password_save (mount_op, G_PASSWORD_SAVE_FOR_SESSION);
 		location = nautilus_file_get_location (file);
 		data = g_new0 (MountNotMountedData, 1);
 		data->cancellable = g_cancellable_new ();
@@ -1925,6 +1926,7 @@ display_view_selection_failure (NautilusWindow *window, NautilusFile *file,
 			detail_message = g_strdup (_("Check that the spelling is correct and that your proxy settings are correct."));
 			break;
 		case G_IO_ERROR_CANCELLED:
+		case G_IO_ERROR_FAILED_HANDLED:
 			g_free (uri_for_display);
 			return;
 			
